// CoMET - The Crimson Fields Map Editing Tool
// Copyright (C) 2002-2003 Jens Granseuer
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//

///////////////////////////////////////////////////////////////
// extwindow2.h - extended window classes for CoMET
//
// Changes:
///////////////////////////////////////////////////////////////

#ifndef _INCLUDE_ED_EXTWINDOW2_H
#define _INCLUDE_ED_EXTWINDOW2_H

#include "window.h"
#include "button.h"
#include "edwidget.h"
#include "misc.h"
#include "mission.h"

// create a new mission
class NewMissionWindow : public Window {
public:
  NewMissionWindow( View *view );

  void SetHook( ButtonHook *hook ) const { ok->SetHook(hook); }

  Point GetMapSize( void ) const;
  const char *GetTileSet( void ) const { return tileset->String(); }
  const char *GetUnitSet( void ) const { return unitset->String(); }

private:
  NumberWidget *m_width;
  NumberWidget *m_height;
  StringWidget *tileset;
  StringWidget *unitset;
  ButtonWidget *ok;
};

#define B_ID_NMW_CREATE  1

class EdBuildingWindow : public Window, public ButtonHook {
public:
  EdBuildingWindow( Building &bld, Unit *first, View *view );

  GUI_Status Activate( ButtonWidget *button, Window *win );

private:
  static const int B_ID_PLAYER   = 1;
  static const int B_ID_WORKSHOP = 2;
  static const int B_ID_FACTORY  = 3;
  static const int B_ID_CRYSTALS = 4;
  static const int B_ID_MINING   = 5;
  static const int B_ID_OK       = 6;
  static const int B_ID_NAME     = 7;
  Building &b;
  Unit *unit;

  StringWidget *b_name;
  CycleWidget *b_player;
  NumberWidget *b_crystals;
  NumberWidget *b_mining;
};


class EdUnitWindow : public Window, public ButtonHook {
public:
  EdUnitWindow( Unit &unit, View *view );

  GUI_Status Activate( ButtonWidget *button, Window *win );

private:
  static const int B_ID_PLAYER    = 1;
  static const int B_ID_DIRECTION = 2;
  static const int B_ID_NAME      = 3;
  static const int B_ID_OK        = 4;
  static const int B_ID_ID        = 5;  // FIXME: remove when proper unit selection is done
  Unit &u;

  CycleWidget *u_player;
};


class EdEventsWindow : public Window, public ButtonHook {
public:
  EdEventsWindow( Mission &mission, View *view );

  GUI_Status Activate( ButtonWidget *button, Window *win );

private:
  void BuildTLWList( const List &events, TLWList &tlwevents ) const;

  static const int B_ID_NEW    = 1;
  static const int B_ID_EDIT   = 2;
  static const int B_ID_DELETE = 3;
  static const int B_ID_OK     = 4;

  TextListWidget *e_list;
  TLWList nodes;
  Mission &mission;
};


class SelectEventWindow : public Window, public ButtonHook {
public:
  SelectEventWindow( Mission &mission, View *view );
  GUI_Status Activate( ButtonWidget *button, Window *win );

private:
  void BuildTLWList( TLWList &list ) const;

  static const int B_ID_TRIGGER = 1;
  static const int B_ID_OK      = 2;
  static const int B_ID_CANCEL  = 3;

  TextListWidget *e_list;
  CycleWidget *e_trigger;
  TLWList nodes;
  Mission &mission;
};


#endif	// _INCLUDE_ED_EXTWINDOW2_H

